@@ -10,7 +10,7 @@ from typing import List, Dict, Optional
 import aioserial
 import pint
 
-from flowchem.components.stdlib import TempControl
+from flowchem.components.properties import TempControl
 from flowchem.exceptions import InvalidConfiguration, DeviceError
 from flowchem.units import flowchem_ureg
 
@@ -49,7 +49,7 @@ class PBCommand:
         return self.command[4:8]
 
     def parse_temperature(self) -> str:
-        """Parse a device temp from hex string to celsius float [two's complement 16 bit signed hex, see manual]"""
+        """Parse a device temp from hex string to celsius float [two's complement 16-bit signed hex, see manual]"""
         temp = (
             (int(self.data, 16) - 65536) / 100
             if int(self.data, 16) > 32767
@@ -65,16 +65,16 @@ class PBCommand:
         return int(self.data, 16)
 
     def parse_rpm(self) -> str:
-        """ Parse a device reply from hexadecimal string to rpm. """
+        """Parse a device reply from hexadecimal string to rpm."""
         return str(flowchem_ureg(f"{self.parse_integer()} rpm"))
 
     def parse_bits(self) -> List[bool]:
-        """ " Parse a device reply from hexadecimal string to 16 constituting bits."""
+        """Parse a device reply from hexadecimal string to 16 constituting bits."""
         bits = f"{int(self.data, 16):016b}"
         return [bool(int(x)) for x in bits]
 
     def parse_boolean(self):
-        """ " Parse a device reply from hexadecimal string (0x0000 or 0x0001) to boolean."""
+        """Parse a device reply from hexadecimal string (0x0000 or 0x0001) to boolean."""
         return self.parse_integer() == 1
 
     def parse_status1(self) -> Dict[str, bool]:
@@ -174,7 +174,7 @@ class HuberChiller(TempControl):
         return PBCommand(reply).parse_temperature()
 
     async def set_temperature_setpoint(self, temp: str):
-        """ Set the set point used by temperature controller. Internal if not probe, otherwise process temp. """
+        """Set the set point used by temperature controller. Internal if not probe, otherwise process temp."""
         min_t = flowchem_ureg(await self.min_setpoint())
         max_t = flowchem_ureg(await self.max_setpoint())
         temp = flowchem_ureg(temp)
@@ -270,7 +270,9 @@ class HuberChiller(TempControl):
     async def set_pump_speed(self, rpm: str):
         """Set the pump speed, in rpm. See device display for range."""
         parsed_rpm = flowchem_ureg(rpm)
-        await self.send_command_and_read_reply("{M48" + self._int_to_string(parsed_rpm.m_as("rpm")))
+        await self.send_command_and_read_reply(
+            "{M48" + self._int_to_string(parsed_rpm.m_as("rpm"))
+        )
 
     async def cooling_water_temp(self) -> str:
         """Returns the cooling water inlet temperature (in Celsius)."""
@@ -306,7 +308,7 @@ class HuberChiller(TempControl):
         return PBCommand(reply).parse_temperature()
 
     async def set_alarm_max_internal_temp(self, temp: str):
-        """ Sets the max internal temp before the alarm is triggered and a fault generated. """
+        """Sets the max internal temp before the alarm is triggered and a fault generated."""
         temp = flowchem_ureg(temp)
         await self.send_command_and_read_reply("{M51" + self._temp_to_string(temp))
 
@@ -316,7 +318,7 @@ class HuberChiller(TempControl):
         return PBCommand(reply).parse_temperature()
 
     async def set_alarm_min_internal_temp(self, temp: str):
-        """ Sets the min internal temp before the alarm is triggered and a fault generated. """
+        """Sets the min internal temp before the alarm is triggered and a fault generated."""
         temp = flowchem_ureg(temp)
         await self.send_command_and_read_reply("{M52" + self._temp_to_string(temp))
 
@@ -326,7 +328,7 @@ class HuberChiller(TempControl):
         return PBCommand(reply).parse_temperature()
 
     async def set_alarm_max_process_temp(self, temp: str):
-        """ Sets the max process temp before the alarm is triggered and a fault generated. """
+        """Sets the max process temp before the alarm is triggered and a fault generated."""
         temp = flowchem_ureg(temp)
         await self.send_command_and_read_reply("{M53" + self._temp_to_string(temp))
 
@@ -336,21 +338,21 @@ class HuberChiller(TempControl):
         return PBCommand(reply).parse_temperature()
 
     async def set_alarm_min_process_temp(self, temp: str):
-        """ Sets the min process temp before the alarm is triggered and a fault generated. """
+        """Sets the min process temp before the alarm is triggered and a fault generated."""
         temp = flowchem_ureg(temp)
         await self.send_command_and_read_reply("{M54" + self._temp_to_string(temp))
 
     async def set_ramp_duration(self, ramp_time: str):
-        """ Sets the duration (in seconds) of a ramp to the temperature set by a later call to ramp_to_temperature. """
+        """Sets the duration (in seconds) of a ramp to the temperature set by a later call to ramp_to_temperature."""
         parsed_time = flowchem_ureg(ramp_time)
-        await self.send_command_and_read_reply("{M59" + self._int_to_string(parsed_time.m_as("s")))
+        await self.send_command_and_read_reply(
+            "{M59" + self._int_to_string(parsed_time.m_as("s"))
+        )
 
     async def ramp_to_temperature(self, temperature: str):
-        """ Sets the duration (in seconds) of a ramp to the temperature set by a later call to start_ramp(). """
+        """Sets the duration (in seconds) of a ramp to the temperature set by a later call to start_ramp()."""
         temp = flowchem_ureg(temperature)
-        await self.send_command_and_read_reply(
-            "{M5A" + self._temp_to_string(temp)
-        )
+        await self.send_command_and_read_reply("{M5A" + self._temp_to_string(temp))
 
     async def is_venting(self) -> bool:
         """Whether the chiller is venting or not."""
@@ -395,30 +397,38 @@ class HuberChiller(TempControl):
 
     @staticmethod
     def _temp_to_string(temp: pint.Quantity) -> str:
-        """ From temperature to string for command. f^-1 of PCommand.parse_temperature. """
-        minT = flowchem_ureg.Quantity(-151, "celsius")
-        maxT = flowchem_ureg.Quantity(327, "celsius")
-        assert minT <= temp <= maxT
+        """From temperature to string for command. f^-1 of PCommand.parse_temperature."""
+        min_temp = flowchem_ureg("-151 °C")
+        max_temp = flowchem_ureg("327 °C")
+        if not isinstance(temp, pint.Quantity):
+            logger.warning(
+                f"Implicit assumption that the temperature provided [{temp}] is in Celsius. Add units pls!"
+            )
+            temp = flowchem_ureg(f"{temp} °C")
+        assert min_temp <= temp <= max_temp
         # Hexadecimal two's complement
         return f"{int(temp.m_as('°C') * 100) & 65535:04X}"
 
     @staticmethod
     def _int_to_string(number: int) -> str:
-        """ From temperature to string for command. f^-1 of PCommand.parse_integer. """
+        """From temperature to string for command. f^-1 of PCommand.parse_integer."""
         return f"{number:04X}"
 
     async def __aenter__(self):
         await self.initialize()
-        await self.set_temperature_setpoint(temp="20 degC")
+        await self.set_temperature_setpoint(temp="20 °C")
+        await self.set_temperature_setpoint(temp="20 °C")
         await self.start_temperature_control()
         await self.start_circulation()
         return self
 
     async def __aexit__(self, exc_type, exc_value, traceback):
-        await self.set_temperature_setpoint("20 C")
+        await self.set_temperature_setpoint("20 °C")
 
         # Wait until close to room temperature before turning off chiller
-        while flowchem_ureg.parse_expression(await self.process_temperature()) > flowchem_ureg.parse_expression("40 degC"):
+        while flowchem_ureg.parse_expression(
+            await self.process_temperature()
+        ) > flowchem_ureg.parse_expression("40 °C"):
             await asyncio.sleep(5)
 
         # Actually turn off chiller
