@@ -24,8 +24,7 @@ class KnauerValve(KnauerEthernetDevice, Valve):
     """
     Control Knauer multi position valves.
 
-    Valve type can be 6, 12, 16
-    or it can be 6 ports, two positions, which will be simply 2 (two states)
+    Valve type can be 6, 12, 16 or it can be 6 ports, two positions, which will be simply 2 (two states)
     in this case, the response for T is LI. Load and inject can be switched by sending L or I
     maybe valves should have an initial state which is set during init and updated, if no  change don't schedule command
     EN: https://www.knauer.net/Dokumente/valves/azura/manuals/v6860_azura_v_2.1s_user-manual_en.pdf
@@ -116,12 +115,14 @@ class KnauerValve(KnauerEthernetDevice, Valve):
 
     async def switch_to_position(self, position: str):
         """Move valve to position."""
-        position = position.upper()
+        position = str(position).upper()
 
         # switching necessary?
         if position == self._position:
             logger.debug("Target position == current position. No movement needed.")
             return
+        else:
+            self._position = position
 
         # Switch to position
         await self._transmit_and_parse_reply(position)
