@@ -1,10 +1,11 @@
+from abc import ABC
 from typing import Optional
 
 from flowchem.units import flowchem_ureg
-from flowchem.components.stdlib import ActiveComponent
+from flowchem.components.properties import ActiveComponent
 
 
-class Pump(ActiveComponent):
+class Pump(ActiveComponent, ABC):
     """
     A generic pumping device whose primary feature is that it moves fluid.
 
@@ -19,5 +20,4 @@ class Pump(ActiveComponent):
     def __init__(self, name: Optional[str] = None):
         super().__init__(name=name)
         self.rate = flowchem_ureg.parse_expression("0 ml/min")
-        self._visualization_shape = "box3d"
         self._base_state = dict(rate="0 mL/min")
