@@ -1,4 +1,3 @@
-""" A vessel with info on the chemical input contained. """
 from ord_schema.proto.reaction_pb2 import ReactionInput
 from typing import Optional
 from flowchem.components.stdlib import Vessel
@@ -23,11 +22,17 @@ class VesselChemicals(Vessel):
         "supported": True,
     }
 
-    def __init__(self, reaction_input: ReactionInput, description: Optional[str] = None, name: Optional[str] = None):
+    def __init__(
+        self,
+        description: Optional[str] = None,
+        name: Optional[str] = None,
+    ):
         super().__init__(name=name, description=description)
-        self.chemical = reaction_input
+        self.chemical = None
 
     def _validate(self, dry_run):
         super(VesselChemicals, self)._validate(dry_run)
 
-        assert isinstance(self.chemical, ReactionInput), "VesselChemicals have a ReactionInput"
+        assert isinstance(
+            self.chemical, ReactionInput
+        ), "VesselChemicals have a ReactionInput"
